@@ -484,6 +484,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -666,6 +667,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
+    "AWS::PaymentCryptography::Alias",
+    "AWS::PaymentCryptography::Key",
     "AWS::Pipes::Pipe",
     "AWS::QuickSight::Analysis",
     "AWS::QuickSight::CustomPermissions",
@@ -765,6 +768,15 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -956,14 +968,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnamev2.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1029,6 +1038,8 @@ cached: list[str] = [
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
+    "aws-athena-namedquery.json",
+    "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
@@ -1047,12 +1058,14 @@ cached: list[str] = [
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
+    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
+    "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
@@ -1329,7 +1342,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1350,7 +1362,6 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
-    "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
@@ -1567,6 +1578,8 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-paymentcryptography-alias.json",
+    "aws-paymentcryptography-key.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
@@ -1628,6 +1641,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
@@ -1684,6 +1698,7 @@ cached: list[str] = [
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-studiolifecycleconfig.json",
+    "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
@@ -1730,6 +1745,15 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -1777,7 +1801,9 @@ cached: list[str] = [
     "aws-systemsmanagersap-application.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
+    "aws-transfer-connector.json",
     "aws-transfer-profile.json",
+    "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
@@ -1797,7 +1823,6 @@ cached: list[str] = [
     "aws-vpclattice-servicenetwork.json",
     "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
-    "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
