@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
     "AWS::AIOps::InvestigationGroup",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -88,6 +89,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -246,6 +248,21 @@ types: list[str] = [
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::Task",
+    "AWS::DataZone::DataSource",
+    "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
+    "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration",
+    "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
+    "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
+    "AWS::DataZone::PolicyGrant",
+    "AWS::DataZone::Project",
+    "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::SubscriptionTarget",
+    "AWS::DataZone::UserProfile",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
     "AWS::Detective::OrganizationAdmin",
@@ -292,6 +309,8 @@ types: list[str] = [
     "AWS::EC2::LocalGatewayRouteTable",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
+    "AWS::EC2::LocalGatewayVirtualInterface",
+    "AWS::EC2::LocalGatewayVirtualInterfaceGroup",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
@@ -444,6 +463,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -529,6 +549,9 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
+    "AWS::KafkaConnect::CustomPlugin",
+    "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -915,15 +938,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -954,6 +973,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -974,6 +994,7 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
@@ -1009,11 +1030,11 @@ cached: list[str] = [
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
-    "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloud9-environmentec2.json",
@@ -1072,6 +1093,7 @@ cached: list[str] = [
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
+    "aws-codepipeline-webhook.json",
     "aws-codestarnotifications-notificationrule.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
@@ -1120,6 +1142,20 @@ cached: list[str] = [
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
+    "aws-datazone-datasource.json",
+    "aws-datazone-domainunit.json",
+    "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
+    "aws-datazone-environmentblueprintconfiguration.json",
+    "aws-datazone-environmentprofile.json",
+    "aws-datazone-formtype.json",
+    "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
+    "aws-datazone-policygrant.json",
+    "aws-datazone-project.json",
+    "aws-datazone-projectmembership.json",
+    "aws-datazone-subscriptiontarget.json",
+    "aws-datazone-userprofile.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
     "aws-detective-organizationadmin.json",
@@ -1175,6 +1211,8 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetable.json",
     "aws-ec2-localgatewayroutetablevirtualinterfacegroupassociation.json",
     "aws-ec2-localgatewayroutetablevpcassociation.json",
+    "aws-ec2-localgatewayvirtualinterface.json",
+    "aws-ec2-localgatewayvirtualinterfacegroup.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
@@ -1231,6 +1269,7 @@ cached: list[str] = [
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
@@ -1255,7 +1294,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1276,7 +1314,6 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
-    "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
@@ -1405,6 +1442,9 @@ cached: list[str] = [
     "aws-iot-thingtype.json",
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
+    "aws-kafkaconnect-connector.json",
+    "aws-kafkaconnect-customplugin.json",
+    "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
@@ -1463,6 +1503,7 @@ cached: list[str] = [
     "aws-mediaconnect-flowvpcinterface.json",
     "aws-mediaconnect-gateway.json",
     "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
@@ -1477,6 +1518,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -1576,14 +1618,16 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
-    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -1649,12 +1693,14 @@ cached: list[str] = [
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
-    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
     "aws-servicecatalog-tagoption.json",
+    "aws-servicecatalog-tagoptionassociation.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
     "aws-servicecatalogappregistry-attributegroupassociation.json",
@@ -1720,7 +1766,6 @@ cached: list[str] = [
     "aws-vpclattice-servicenetwork.json",
     "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
-    "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-ipset.json",
