@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -151,6 +152,8 @@ types: list[str] = [
     "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
+    "AWS::BedrockAgentCore::Gateway",
+    "AWS::BedrockAgentCore::GatewayTarget",
     "AWS::Budgets::Budget",
     "AWS::Budgets::BudgetsAction",
     "AWS::CDK::Metadata",
@@ -378,6 +381,7 @@ types: list[str] = [
     "AWS::DocDBElastic::Cluster",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
+    "AWS::EC2::CapacityManagerDataExport",
     "AWS::EC2::CapacityReservation",
     "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::CarrierGateway",
@@ -585,6 +589,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -771,6 +776,7 @@ types: list[str] = [
     "AWS::Lightsail::Container",
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
+    "AWS::Lightsail::DiskSnapshot",
     "AWS::Lightsail::Instance",
     "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
@@ -1073,6 +1079,7 @@ types: list[str] = [
     "AWS::SES::MailManagerRelay",
     "AWS::SES::MailManagerRuleSet",
     "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -1109,6 +1116,7 @@ types: list[str] = [
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
+    "AWS::SSMQuickSetup::LifecycleAutomation",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -1308,14 +1316,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnamev2.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1385,10 +1390,12 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -1417,6 +1424,7 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-datasource.json",
@@ -1428,12 +1436,13 @@ cached: list[str] = [
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
+    "aws-bedrockagentcore-gateway.json",
+    "aws-bedrockagentcore-gatewaytarget.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
-    "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
@@ -1652,6 +1661,7 @@ cached: list[str] = [
     "aws-dsql-cluster.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
+    "aws-ec2-capacitymanagerdataexport.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1773,7 +1783,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -2024,6 +2033,7 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -2042,6 +2052,7 @@ cached: list[str] = [
     "aws-lightsail-container.json",
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
+    "aws-lightsail-disksnapshot.json",
     "aws-lightsail-instance.json",
     "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
@@ -2141,15 +2152,21 @@ cached: list[str] = [
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
+    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-observabilityadmin-organizationcentralizationrule.json",
@@ -2293,7 +2310,6 @@ cached: list[str] = [
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
-    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -2338,7 +2354,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -2374,6 +2389,7 @@ cached: list[str] = [
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolio.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-serviceaction.json",
@@ -2403,6 +2419,7 @@ cached: list[str] = [
     "aws-ses-mailmanagerrelay.json",
     "aws-ses-mailmanagerruleset.json",
     "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -2445,6 +2462,7 @@ cached: list[str] = [
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-ssmquicksetup-configurationmanager.json",
+    "aws-ssmquicksetup-lifecycleautomation.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -2470,15 +2488,17 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
     "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
-    "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-ipset.json",
