@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -84,6 +85,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -227,6 +229,21 @@ types: list[str] = [
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::Task",
+    "AWS::DataZone::DataSource",
+    "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
+    "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration",
+    "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
+    "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
+    "AWS::DataZone::PolicyGrant",
+    "AWS::DataZone::Project",
+    "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::SubscriptionTarget",
+    "AWS::DataZone::UserProfile",
     "AWS::DirectoryService::MicrosoftAD",
     "AWS::DirectoryService::SimpleAD",
     "AWS::DynamoDB::GlobalTable",
@@ -465,6 +482,9 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
+    "AWS::KafkaConnect::CustomPlugin",
+    "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -648,6 +668,15 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
     "AWS::SMSVOICE::ConfigurationSet",
@@ -804,14 +833,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnamev2.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -842,6 +868,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -861,10 +888,12 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -957,6 +986,7 @@ cached: list[str] = [
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
+    "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
@@ -997,6 +1027,20 @@ cached: list[str] = [
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
+    "aws-datazone-datasource.json",
+    "aws-datazone-domainunit.json",
+    "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
+    "aws-datazone-environmentblueprintconfiguration.json",
+    "aws-datazone-environmentprofile.json",
+    "aws-datazone-formtype.json",
+    "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
+    "aws-datazone-policygrant.json",
+    "aws-datazone-project.json",
+    "aws-datazone-projectmembership.json",
+    "aws-datazone-subscriptiontarget.json",
+    "aws-datazone-userprofile.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
@@ -1027,7 +1071,6 @@ cached: list[str] = [
     "aws-ec2-ipampoolcidr.json",
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
-    "aws-ec2-ipamscope.json",
     "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
@@ -1039,6 +1082,7 @@ cached: list[str] = [
     "aws-ec2-networkinsightsanalysis.json",
     "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
+    "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkperformancemetricsubscription.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
@@ -1095,7 +1139,6 @@ cached: list[str] = [
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
-    "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
@@ -1110,7 +1153,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1127,7 +1169,6 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
-    "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
@@ -1219,6 +1260,9 @@ cached: list[str] = [
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kafkaconnect-connector.json",
+    "aws-kafkaconnect-customplugin.json",
+    "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
@@ -1236,6 +1280,7 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1266,6 +1311,7 @@ cached: list[str] = [
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
@@ -1308,6 +1354,7 @@ cached: list[str] = [
     "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-quicksight-analysis.json",
+    "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
@@ -1323,6 +1370,8 @@ cached: list[str] = [
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
+    "aws-rds-dbproxy.json",
+    "aws-rds-dbproxyendpoint.json",
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
@@ -1355,6 +1404,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
@@ -1365,10 +1415,13 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1396,7 +1449,6 @@ cached: list[str] = [
     "aws-sagemaker-modelpackagegroup.json",
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-scheduler-schedule.json",
@@ -1419,12 +1471,15 @@ cached: list[str] = [
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
     "aws-servicecatalog-tagoption.json",
+    "aws-servicecatalog-tagoptionassociation.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
     "aws-servicecatalogappregistry-attributegroupassociation.json",
@@ -1439,6 +1494,15 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
     "aws-shield-drtaccess.json",
@@ -1491,13 +1555,14 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
-    "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
