@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
     "AWS::AIOps::InvestigationGroup",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -69,6 +70,19 @@ types: list[str] = [
     "AWS::AppMesh::VirtualNode",
     "AWS::AppMesh::VirtualRouter",
     "AWS::AppMesh::VirtualService",
+    "AWS::AppStream::AppBlock",
+    "AWS::AppStream::AppBlockBuilder",
+    "AWS::AppStream::Application",
+    "AWS::AppStream::ApplicationEntitlementAssociation",
+    "AWS::AppStream::ApplicationFleetAssociation",
+    "AWS::AppStream::DirectoryConfig",
+    "AWS::AppStream::Entitlement",
+    "AWS::AppStream::Fleet",
+    "AWS::AppStream::ImageBuilder",
+    "AWS::AppStream::Stack",
+    "AWS::AppStream::StackFleetAssociation",
+    "AWS::AppStream::StackUserAssociation",
+    "AWS::AppStream::User",
     "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
@@ -875,14 +889,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnamev2.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -922,6 +933,16 @@ cached: list[str] = [
     "aws-appmesh-virtualnode.json",
     "aws-appmesh-virtualrouter.json",
     "aws-appmesh-virtualservice.json",
+    "aws-appstream-appblock.json",
+    "aws-appstream-appblockbuilder.json",
+    "aws-appstream-application.json",
+    "aws-appstream-applicationentitlementassociation.json",
+    "aws-appstream-applicationfleetassociation.json",
+    "aws-appstream-directoryconfig.json",
+    "aws-appstream-entitlement.json",
+    "aws-appstream-fleet.json",
+    "aws-appstream-stack.json",
+    "aws-appstream-stackfleetassociation.json",
     "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
@@ -934,9 +955,9 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
-    "aws-aps-scraper.json",
     "aws-aps-workspace.json",
     "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
@@ -966,6 +987,7 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
@@ -1014,6 +1036,7 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -1200,7 +1223,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1217,7 +1239,6 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
-    "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
@@ -1361,7 +1382,7 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1376,14 +1397,17 @@ cached: list[str] = [
     "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
@@ -1507,6 +1531,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
@@ -1554,7 +1579,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-scheduler-schedule.json",
@@ -1584,6 +1608,7 @@ cached: list[str] = [
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
     "aws-servicecatalog-tagoption.json",
+    "aws-servicecatalog-tagoptionassociation.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
     "aws-servicecatalogappregistry-attributegroupassociation.json",
@@ -1652,7 +1677,6 @@ cached: list[str] = [
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
-    "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
