@@ -176,6 +176,7 @@ types: list[str] = [
     "AWS::BedrockAgentCore::Memory",
     "AWS::BedrockAgentCore::Runtime",
     "AWS::BedrockAgentCore::RuntimeEndpoint",
+    "AWS::BedrockAgentCore::WorkloadIdentity",
     "AWS::Billing::BillingView",
     "AWS::BillingConductor::BillingGroup",
     "AWS::BillingConductor::CustomLineItem",
@@ -650,6 +651,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IntegrationResourceProperty",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -932,6 +934,9 @@ types: list[str] = [
     "AWS::MediaConnect::FlowSource",
     "AWS::MediaConnect::FlowVpcInterface",
     "AWS::MediaConnect::Gateway",
+    "AWS::MediaConnect::RouterInput",
+    "AWS::MediaConnect::RouterNetworkInterface",
+    "AWS::MediaConnect::RouterOutput",
     "AWS::MediaConvert::JobTemplate",
     "AWS::MediaConvert::Preset",
     "AWS::MediaConvert::Queue",
@@ -1133,6 +1138,7 @@ types: list[str] = [
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
+    "AWS::RTBFabric::InboundExternalLink",
     "AWS::RTBFabric::Link",
     "AWS::RTBFabric::RequesterGateway",
     "AWS::RTBFabric::ResponderGateway",
@@ -1244,6 +1250,7 @@ types: list[str] = [
     "AWS::SES::MailManagerRelay",
     "AWS::SES::MailManagerRuleSet",
     "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -1475,6 +1482,7 @@ types: list[str] = [
     "AWS::XRay::SamplingRule",
     "AWS::XRay::TransactionSearchConfig",
     "Alexa::ASK::Skill",
+    "Dev::FSx::StorageVirtualMachine",
     "Module",
 ]
 cached: list[str] = []
