@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
     "AWS::AIOps::InvestigationGroup",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -163,9 +164,12 @@ types: list[str] = [
     "AWS::Bedrock::PromptVersion",
     "AWS::BedrockAgentCore::BrowserCustom",
     "AWS::BedrockAgentCore::CodeInterpreterCustom",
+    "AWS::BedrockAgentCore::Gateway",
+    "AWS::BedrockAgentCore::GatewayTarget",
     "AWS::BedrockAgentCore::Memory",
     "AWS::BedrockAgentCore::Runtime",
     "AWS::BedrockAgentCore::RuntimeEndpoint",
+    "AWS::BedrockAgentCore::WorkloadIdentity",
     "AWS::Budgets::Budget",
     "AWS::Budgets::BudgetsAction",
     "AWS::CDK::Metadata",
@@ -369,6 +373,7 @@ types: list[str] = [
     "AWS::DocDBElastic::Cluster",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
+    "AWS::EC2::CapacityManagerDataExport",
     "AWS::EC2::CapacityReservation",
     "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::CarrierGateway",
@@ -596,6 +601,7 @@ types: list[str] = [
     "AWS::Glue::DataQualityRuleset",
     "AWS::Glue::Database",
     "AWS::Glue::DevEndpoint",
+    "AWS::Glue::IdentityCenterConfiguration",
     "AWS::Glue::Job",
     "AWS::Glue::MLTransform",
     "AWS::Glue::Partition",
@@ -772,6 +778,7 @@ types: list[str] = [
     "AWS::Lightsail::Container",
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
+    "AWS::Lightsail::DiskSnapshot",
     "AWS::Lightsail::Instance",
     "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
@@ -1056,6 +1063,9 @@ types: list[str] = [
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::S3Tables::TablePolicy",
+    "AWS::S3Vectors::Index",
+    "AWS::S3Vectors::VectorBucket",
+    "AWS::S3Vectors::VectorBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1070,6 +1080,7 @@ types: list[str] = [
     "AWS::SES::MailManagerRelay",
     "AWS::SES::MailManagerRuleSet",
     "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -1106,6 +1117,7 @@ types: list[str] = [
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
+    "AWS::SSMQuickSetup::LifecycleAutomation",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -1302,14 +1314,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
-    "aws-apigateway-domainnamev2.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1364,7 +1373,6 @@ cached: list[str] = [
     "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
     "aws-appstream-entitlement.json",
-    "aws-appstream-fleet.json",
     "aws-appstream-imagebuilder.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
@@ -1380,6 +1388,7 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
@@ -1419,6 +1428,7 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-automatedreasoningpolicy.json",
@@ -1427,7 +1437,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-intelligentpromptrouter.json",
     "aws-bedrock-knowledgebase.json",
@@ -1435,9 +1444,12 @@ cached: list[str] = [
     "aws-bedrock-promptversion.json",
     "aws-bedrockagentcore-browsercustom.json",
     "aws-bedrockagentcore-codeinterpretercustom.json",
+    "aws-bedrockagentcore-gateway.json",
+    "aws-bedrockagentcore-gatewaytarget.json",
     "aws-bedrockagentcore-memory.json",
     "aws-bedrockagentcore-runtime.json",
     "aws-bedrockagentcore-runtimeendpoint.json",
+    "aws-bedrockagentcore-workloadidentity.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
@@ -1579,9 +1591,7 @@ cached: list[str] = [
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
-    "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
-    "aws-datazone-domain.json",
     "aws-datazone-domainunit.json",
     "aws-datazone-environment.json",
     "aws-datazone-environmentactions.json",
@@ -1638,6 +1648,7 @@ cached: list[str] = [
     "aws-dsql-cluster.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
+    "aws-ec2-capacitymanagerdataexport.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1764,7 +1775,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -2036,6 +2046,7 @@ cached: list[str] = [
     "aws-lightsail-container.json",
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
+    "aws-lightsail-disksnapshot.json",
     "aws-lightsail-instance.json",
     "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
@@ -2141,15 +2152,21 @@ cached: list[str] = [
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
+    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-observabilityadmin-organizationcentralizationrule.json",
@@ -2312,6 +2329,9 @@ cached: list[str] = [
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-s3tables-tablepolicy.json",
+    "aws-s3vectors-index.json",
+    "aws-s3vectors-vectorbucket.json",
+    "aws-s3vectors-vectorbucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-cluster.json",
@@ -2341,7 +2361,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -2377,8 +2396,10 @@ cached: list[str] = [
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolio.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
+    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -2406,6 +2427,7 @@ cached: list[str] = [
     "aws-ses-mailmanagerrelay.json",
     "aws-ses-mailmanagerruleset.json",
     "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -2449,6 +2471,7 @@ cached: list[str] = [
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-ssmquicksetup-configurationmanager.json",
+    "aws-ssmquicksetup-lifecycleautomation.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -2481,15 +2504,17 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
     "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
-    "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-ipset.json",
