@@ -831,15 +831,11 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -891,6 +887,8 @@ cached: list[str] = [
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
+    "aws-athena-namedquery.json",
+    "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
@@ -906,6 +904,7 @@ cached: list[str] = [
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
+    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
@@ -1034,7 +1033,6 @@ cached: list[str] = [
     "aws-ec2-ipampoolcidr.json",
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
-    "aws-ec2-ipamscope.json",
     "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
@@ -1108,7 +1106,6 @@ cached: list[str] = [
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
-    "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
@@ -1122,7 +1119,6 @@ cached: list[str] = [
     "aws-eks-addon.json",
     "aws-eks-cluster.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1139,7 +1135,6 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
-    "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
@@ -1151,6 +1146,7 @@ cached: list[str] = [
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
     "aws-events-archive.json",
+    "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
@@ -1275,6 +1271,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1439,6 +1436,7 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-studiolifecycleconfig.json",
+    "aws-sagemaker-userprofile.json",
     "aws-scheduler-schedule.json",
     "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
@@ -1461,10 +1459,8 @@ cached: list[str] = [
     "aws-securitylake-datalake.json",
     "aws-securitylake-subscriber.json",
     "aws-securitylake-subscribernotification.json",
-    "aws-servicecatalog-cloudformationproduct.json",
     "aws-servicecatalog-cloudformationprovisionedproduct.json",
     "aws-servicecatalog-launchroleconstraint.json",
-    "aws-servicecatalog-portfolioprincipalassociation.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
@@ -1522,7 +1518,9 @@ cached: list[str] = [
     "aws-synthetics-group.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
+    "aws-transfer-connector.json",
     "aws-transfer-profile.json",
+    "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
